@@ -13,17 +13,12 @@
 #include <dune/common/assertandreturn.hh>
 #include <dune/common/exceptions.hh>
 #include <dune/common/parallel/mpihelper.hh>
-#include <dune/common/unused.hh>
-
 
 struct Foo
 {
-  static constexpr auto lessAndReturn(int a, int b, int x)
+  static constexpr auto lessAndReturn([[maybe_unused]] int a, [[maybe_unused]] int b, int x)
   {
     return DUNE_ASSERT_AND_RETURN(a<b, x);
-#ifdef NDEBUG
-    DUNE_UNUSED_PARAMETER(a), DUNE_UNUSED_PARAMETER(b);
-#endif
   }
 };
 
