@@ -7,7 +7,6 @@
 #include <dune/common/exceptions.hh>
 #include <dune/common/fvector.hh>
 #include <dune/common/fmatrix.hh>
-#include <dune/common/unused.hh>
 
 int main() try {
   bool passed = true;
@@ -27,7 +26,7 @@ int main() try {
   // Read beyond end of singleton vector
   try {
     Dune::FieldVector<double, 1> const v = {1};
-    DUNE_UNUSED double const x = v[1];
+    [[maybe_unused]] double const x = v[1];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -61,7 +60,7 @@ int main() try {
   // Read beyond end of vector
   try {
     Dune::FieldVector<double, 3> const v = {1, 2, 3};
-    DUNE_UNUSED double const x = v[3];
+    [[maybe_unused]] double const x = v[3];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -71,7 +70,7 @@ int main() try {
   }
   try {
     Dune::DynamicVector<double> const v = {1, 2, 3};
-    DUNE_UNUSED double const x = v[3];
+    [[maybe_unused]] double const x = v[3];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -96,7 +95,7 @@ int main() try {
   // Read beyond end of singleton matrix
   try {
     Dune::FieldMatrix<double, 1, 1> const m = {{1}};
-    DUNE_UNUSED double const x = m[1][0];
+    [[maybe_unused]] double const x = m[1][0];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -130,7 +129,7 @@ int main() try {
   // Read beyond end of matrix
   try {
     Dune::FieldMatrix<double, 2, 3> const m = {{1, 2, 3}, {10, 20, 30}};
-    DUNE_UNUSED double const x = m[2][0];
+    [[maybe_unused]] double const x = m[2][0];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -140,7 +139,7 @@ int main() try {
   }
   try {
     Dune::DynamicMatrix<double> const m = {{1, 2, 3}, {10, 20, 30}};
-    DUNE_UNUSED double const x = m[2][0];
+    [[maybe_unused]] double const x = m[2][0];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -175,7 +174,7 @@ int main() try {
   // Read beyond end of diagonal matrix (way #1)
   try {
     Dune::DiagonalMatrix<double, 3> const d(5);
-    DUNE_UNUSED double const x = d[3][3];
+    [[maybe_unused]] double const x = d[3][3];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -186,7 +185,7 @@ int main() try {
   // Read beyond end of diagonal matrix (way #2)
   try {
     Dune::DiagonalMatrix<double, 3> const d(5);
-    DUNE_UNUSED double const x = d.diagonal(3);
+    [[maybe_unused]] double const x = d.diagonal(3);
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -210,7 +209,7 @@ int main() try {
   // Read outside of diagonal matrix pattern
   try {
     Dune::DiagonalMatrix<double, 3> const d(5);
-    DUNE_UNUSED double const x = d[1][2];
+    [[maybe_unused]] double const x = d[1][2];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -246,7 +245,7 @@ int main() try {
   // Read beyond end of bitsetvector
   try {
     Dune::BitSetVector<3> const b(10);
-    DUNE_UNUSED auto const x = b[10];
+    [[maybe_unused]] auto const x = b[10];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
@@ -270,7 +269,7 @@ int main() try {
   // Read beyond end of bitsetvectorreference
   try {
     Dune::BitSetVector<3> const b(10);
-    DUNE_UNUSED auto const x = b[10][3];
+    [[maybe_unused]] auto const x = b[10][3];
     std::cout << "(line " << __LINE__ << ") Error: No exception thrown."
               << std::endl;
     passed = false;
