@@ -17,6 +17,7 @@
 
 #include <dune/common/classname.hh>
 #include <dune/common/fmatrix.hh>
+#include <dune/common/fmatrixev.hh>
 #include <dune/common/ftraits.hh>
 #include <dune/common/quadmath.hh>
 #include <dune/common/rangeutilities.hh>
@@ -25,7 +26,6 @@
 #if HAVE_VC
 #include <dune/common/simd/vc.hh>
 #endif
-#include <dune/common/unused.hh>
 
 #include "checkmatrixinterface.hh"
 
@@ -248,6 +248,10 @@ void test_matrix()
   FieldVector<K2,m> v;
   FieldVector<K3,n> f;
 
+  // test constexpr size
+  static_assert(A.N() == n, "");
+  static_assert(A.M() == m, "");
+
   // assign matrix
   A=K();
   // random access matrix
@@ -372,7 +376,7 @@ void test_matrix()
       if (tmp.infinity_norm() > 1e-12)
         DUNE_THROW(FMatrixError, "Return value of Operator*= incorrect!");
     }
-    FM DUNE_UNUSED A3 = (A2 *= 3); // A2 == A3 == 6*A
+    [[maybe_unused]] FM A3 = (A2 *= 3); // A2 == A3 == 6*A
     FM A4 = (A2 /= 2); // A2 == A4 == 3*A;
     FM A5 = A;
     A5 *= 3;           // A5       == 3*A
@@ -489,7 +493,7 @@ void test_matrix()
         return AT;
       };
 
-      DUNE_UNUSED auto product = transposed(A) * A;
+      [[maybe_unused]] auto product = transposed(A) * A;
     }
 
   }
@@ -609,7 +613,7 @@ struct ScalarOperatorTest
     ft c = 2;
     FieldMatrix<ft,1,1> v(2);
     FieldMatrix<ft,1,1> w(2);
-    bool b DUNE_UNUSED;
+    [[maybe_unused]] bool b;
 
     std::cout << __func__ << "\t ( " << className(v) << " )" << std::endl;
 
@@ -827,7 +831,7 @@ void test_interface()
 
 void test_initialisation()
 {
-  DUNE_UNUSED Dune::FieldMatrix<int, 2, 2> const A = {
+  [[maybe_unused]] Dune::FieldMatrix<int, 2, 2> const A = {
     { 1, 2 },
     { 3, 4 }
   };
